===========================
Usage via command line
===========================


The pipeline provides a command line tool ``cellmaps_pipelinecmd.py`` that can run
the pipeline serially or in parallel via `SLURM`_ For more information run the following:

.. code-block:: python

    cellmaps_pipelinecmd.py -h

.. _CM4AI data: https://cm4ai.org/data
.. _RO-Crate: https://www.researchobject.org/ro-crate/
.. _Human Protein Atlas: https://www.proteinatlas.org
.. _Bioplex: https://bioplex.hms.harvard.edu
.. _cellmaps_pipeline: https://github.com/idekerlab/cellmaps_pipeline
.. _JSON: https://www.json.org/json-en.html
.. _SLURM: https://slurm.schedmd.com/documentation.html
